@@ -2,5 +2,4 @@ __author__ = "Aaron Levi Can (aaronlyy)"
 __version__ = "0.1.7.1"
 
 from .shell import Shell
-from .commands import clear
-
+from .commands import *
\ No newline at end of file
